==> chaosmesh-model-5.2.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface JVMChaosListFluent<A extends JVMChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,JVMChaos item);
    public A setToItems(int index,JVMChaos item);
    public A addToItems(JVMChaos... items);
    public A addAllToItems(Collection<JVMChaos> items);
    public A removeFromItems(JVMChaos... items);
    public A removeAllFromItems(Collection<JVMChaos> items);
    public A removeMatchingFromItems(Predicate<JVMChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<JVMChaos> getItems();
    public List<JVMChaos> buildItems();
    public JVMChaos buildItem(int index);
    public JVMChaos buildFirstItem();
    public JVMChaos buildLastItem();
    public JVMChaos buildMatchingItem(Predicate<JVMChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<JVMChaosBuilder> predicate);
    public A withItems(List<JVMChaos> items);
    public A withItems(JVMChaos... items);
    public Boolean hasItems();
    public JVMChaosListFluent.ItemsNested<A> addNewItem();
    public JVMChaosListFluent.ItemsNested<A> addNewItemLike(JVMChaos item);
    public JVMChaosListFluent.ItemsNested<A> setNewItemLike(int index,JVMChaos item);
    public JVMChaosListFluent.ItemsNested<A> editItem(int index);
    public JVMChaosListFluent.ItemsNested<A> editFirstItem();
    public JVMChaosListFluent.ItemsNested<A> editLastItem();
    public JVMChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<JVMChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JVMChaosFluent<JVMChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}

==> chaosmesh-model-5.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMChaosListFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.util.function.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface JVMChaosListFluent<A extends JVMChaosListFluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    public A addToItems(int index,JVMChaos item);
    public A setToItems(int index,JVMChaos item);
    public A addToItems(JVMChaos... items);
    public A addAllToItems(Collection<JVMChaos> items);
    public A removeFromItems(JVMChaos... items);
    public A removeAllFromItems(Collection<JVMChaos> items);
    public A removeMatchingFromItems(Predicate<JVMChaosBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<JVMChaos> getItems();
    public List<JVMChaos> buildItems();
    public JVMChaos buildItem(int index);
    public JVMChaos buildFirstItem();
    public JVMChaos buildLastItem();
    public JVMChaos buildMatchingItem(Predicate<JVMChaosBuilder> predicate);
    public Boolean hasMatchingItem(Predicate<JVMChaosBuilder> predicate);
    public A withItems(List<JVMChaos> items);
    public A withItems(JVMChaos... items);
    public Boolean hasItems();
    public JVMChaosListFluent.ItemsNested<A> addNewItem();
    public JVMChaosListFluent.ItemsNested<A> addNewItemLike(JVMChaos item);
    public JVMChaosListFluent.ItemsNested<A> setNewItemLike(int index,JVMChaos item);
    public JVMChaosListFluent.ItemsNested<A> editItem(int index);
    public JVMChaosListFluent.ItemsNested<A> editFirstItem();
    public JVMChaosListFluent.ItemsNested<A> editLastItem();
    public JVMChaosListFluent.ItemsNested<A> editMatchingItem(Predicate<JVMChaosBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(int[] arg1,int arg2,int arg3);
    public A withNewKind(char[] arg1);
    public A withNewKind(StringBuffer arg1);
    public A withNewKind(byte[] arg1,int arg2);
    public A withNewKind(byte[] arg1);
    public A withNewKind(char[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3);
    public A withNewKind(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewKind(String arg1);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public Boolean hasMetadata();
    public A withNewMetadata(String _continue,Long remainingItemCount,String resourceVersion,String selfLink);
    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,JVMChaosFluent<JVMChaosListFluent.ItemsNested<N>> {

            public N and();
            public N endItem();    }


}
